@@ -1,6 +1,6 @@
 /*
  * hfsutils - tools for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,49 +15,56 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * $Id: hcopy.c,v 1.11 1998/01/08 21:13:07 rob Exp $
  */
 
+# ifdef HAVE_CONFIG_H
+#  include "config.h"
+# endif
+
+# ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+# endif
+
 # include <stdio.h>
 # include <stdlib.h>
 # include <string.h>
-# include <sys/stat.h>
-# include <unistd.h>
-# include <fcntl.h>
 # include <errno.h>
+# include <sys/stat.h>
 
 # include "hfs.h"
 # include "hcwd.h"
 # include "hfsutil.h"
-# include "glob.h"
 # include "hcopy.h"
 # include "copyin.h"
 # include "copyout.h"
 
 extern int optind;
 
-typedef int (*cpifunc)(char *, hfsvol *, char *);
-typedef int (*cpofunc)(hfsvol *, char *, char *);
-
 /*
- * NAME:	ufs->automode()
- * DESCRIPTION:	automatically choose copyin transfer mode
+ * NAME:	automode_unix()
+ * DESCRIPTION:	automatically choose copyin transfer mode for UNIX path
  */
 static
-cpifunc ufs_automode(char *path)
+cpifunc automode_unix(const char *path)
 {
   int i;
   struct {
-    char *ext;
+    const char *ext;
     cpifunc func;
   } exts[] = {
-    { ".bin", cpi_macb },
-    { ".hqx", cpi_binh },
+    { ".bin",  cpi_macb },
+    { ".hqx",  cpi_binh },
 
-    { ".txt", cpi_text },
-    { ".c",   cpi_text },
-    { ".h",   cpi_text },
+    { ".txt",  cpi_text },
+    { ".c",    cpi_text },
+    { ".h",    cpi_text },
+    { ".html", cpi_text },
+    { ".htm",  cpi_text },
+    { ".rtf",  cpi_text },
 
-    { 0,      0        }
+    { 0,       0        }
   };
 
   path += strlen(path);
@@ -76,17 +83,18 @@ cpifunc ufs_automode(char *path)
  * DESCRIPTION:	copy files from UNIX to HFS
  */
 static
-int do_copyin(hfsvol *vol, int argc, char *argv[], char *dest, int mode)
+int do_copyin(hfsvol *vol, int argc, char *argv[], const char *dest, int mode)
 {
   hfsdirent ent;
+  struct stat sbuf;
   cpifunc copyfile;
   int i, result = 0;
 
-  if (argc > 1 && (hfs_stat(vol, dest, &ent) < 0 ||
+  if (argc > 1 && (hfs_stat(vol, dest, &ent) == -1 ||
 		   ! (ent.flags & HFS_ISDIR)))
     {
       ERROR(ENOTDIR, 0);
-      hfs_perrorp(dest);
+      hfsutil_perrorp(dest);
 
       return 1;
     }
@@ -112,38 +120,49 @@ int do_copyin(hfsvol *vol, int argc, char *argv[], char *dest, int mode)
 
   for (i = 0; i < argc; ++i)
     {
-      if (mode == 'a')
-	copyfile = ufs_automode(argv[i]);
-
-      if (copyfile(argv[i], vol, dest) < 0)
+      if (stat(argv[i], &sbuf) != -1 &&
+	  S_ISDIR(sbuf.st_mode))
 	{
-	  ERROR(0, cpi_error);
-	  hfs_perrorp(argv[i]);
+	  ERROR(EISDIR, 0);
+	  hfsutil_perrorp(argv[i]);
 
 	  result = 1;
 	}
+      else
+	{
+	  if (mode == 'a')
+	    copyfile = automode_unix(argv[i]);
+
+	  if (copyfile(argv[i], vol, dest) == -1)
+	    {
+	      ERROR(errno, cpi_error);
+	      hfsutil_perrorp(argv[i]);
+
+	      result = 1;
+	    }
+	}
     }
 
   return result;
 }
 
 /*
- * NAME:	hfs->automode()
- * DESCRIPTION:	automatically choose copyout transfer mode
+ * NAME:	automode_hfs()
+ * DESCRIPTION:	automatically choose copyout transfer mode for HFS path
  */
 static
-cpofunc hfs_automode(hfsvol *vol, char *path)
+cpofunc automode_hfs(hfsvol *vol, const char *path)
 {
   hfsdirent ent;
 
-  if (hfs_stat(vol, path, &ent) < 0)
-    return cpo_macb;
-
-  if (strcmp(ent.type, "TEXT") == 0 ||
-      strcmp(ent.type, "ttro") == 0)
-    return cpo_text;
-  else if (ent.rsize == 0)
-    return cpo_raw;
+  if (hfs_stat(vol, path, &ent) != -1)
+    {
+      if (strcmp(ent.u.file.type, "TEXT") == 0 ||
+	  strcmp(ent.u.file.type, "ttro") == 0)
+	return cpo_text;
+      else if (ent.u.file.rsize == 0)
+	return cpo_raw;
+    }
 
   return cpo_macb;
 }
@@ -153,17 +172,18 @@ cpofunc hfs_automode(hfsvol *vol, char *path)
  * DESCRIPTION:	copy files from HFS to UNIX
  */
 static
-int do_copyout(hfsvol *vol, int argc, char *argv[], char *dest, int mode)
+int do_copyout(hfsvol *vol, int argc, char *argv[], const char *dest, int mode)
 {
   struct stat sbuf;
+  hfsdirent ent;
   cpofunc copyfile;
   int i, result = 0;
 
-  if (argc > 1 && (stat(dest, &sbuf) < 0 ||
+  if (argc > 1 && (stat(dest, &sbuf) == -1 ||
 		   ! S_ISDIR(sbuf.st_mode)))
     {
       ERROR(ENOTDIR, 0);
-      hfs_perrorp(dest);
+      hfsutil_perrorp(dest);
 
       return 1;
     }
@@ -189,16 +209,27 @@ int do_copyout(hfsvol *vol, int argc, char *argv[], char *dest, int mode)
 
   for (i = 0; i < argc; ++i)
     {
-      if (mode == 'a')
-	copyfile = hfs_automode(vol, argv[i]);
-
-      if (copyfile(vol, argv[i], dest) < 0)
+      if (hfs_stat(vol, argv[i], &ent) != -1 &&
+	  (ent.flags & HFS_ISDIR))
 	{
-	  ERROR(0, cpo_error);
-	  hfs_perrorp(argv[i]);
+	  ERROR(EISDIR, 0);
+	  hfsutil_perrorp(argv[i]);
 
 	  result = 1;
 	}
+      else
+	{
+	  if (mode == 'a')
+	    copyfile = automode_hfs(vol, argv[i]);
+
+	  if (copyfile(vol, argv[i], dest) == -1)
+	    {
+	      ERROR(errno, cpo_error);
+	      hfsutil_perrorp(argv[i]);
+
+	      result = 1;
+	    }
+	}
     }
 
   return result;
@@ -223,12 +254,12 @@ int usage(void)
  */
 int hcopy_main(int argc, char *argv[])
 {
-  int nargs, mode = 'a', result;
-  char *target;
+  int nargs, mode = 'a', result = 0;
+  const char *target;
   int fargc;
   char **fargv;
   hfsvol *vol;
-  int (*copy)(hfsvol *, int, char *[], char *, int);
+  int (*copy)(hfsvol *, int, char *[], const char *, int);
 
   while (1)
     {
@@ -257,7 +288,7 @@ int hcopy_main(int argc, char *argv[])
 
   if (strchr(target, ':') && target[0] != '.' && target[0] != '/')
     {
-      vol = hfs_remount(hcwd_getvol(-1), O_RDWR);
+      vol = hfsutil_remount(hcwd_getvol(-1), HFS_MODE_ANY);
       if (vol == 0)
 	return 1;
 
@@ -267,27 +298,18 @@ int hcopy_main(int argc, char *argv[])
     }
   else
     {
-      vol = hfs_remount(hcwd_getvol(-1), O_RDONLY);
+      vol = hfsutil_remount(hcwd_getvol(-1), HFS_MODE_RDONLY);
       if (vol == 0)
 	return 1;
 
       copy  = do_copyout;
-      fargv = hfs_glob(vol, nargs - 1, &argv[optind], &fargc);
+      fargv = hfsutil_glob(vol, nargs - 1, &argv[optind], &fargc, &result);
     }
 
-  if (fargv == 0)
-    {
-      fprintf(stderr, "%s: globbing error\n", argv0);
-      result = 1;
-    }
-  else
+  if (result == 0)
     result = copy(vol, fargc, fargv, target, mode);
 
-  if (hfs_umount(vol) < 0 && result == 0)
-    {
-      hfs_perror("Error closing HFS volume");
-      result = 1;
-    }
+  hfsutil_unmount(vol, &result);
 
   if (fargv && fargv != &argv[optind])
     free(fargv);
