@@ -16,10 +16,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: main.c,v 1.9 1997/11/11 21:36:47 rob Exp rob $
+ * $Id: main.c,v 1.11 1998/02/19 20:15:22 rob Exp $
  */
 
 # include <stdio.h>
+# include <stdlib.h>
 # include <string.h>
 # include <unistd.h>
 # include <sys/types.h>
@@ -114,13 +115,49 @@ int main(int argc, char *argv[])
   nparts = hfs_nparts(path);
   suid_disable();
 
+  if (nparts == 0)
+    {
+      fprintf(stderr, "%s: partitioned medium contains no HFS partitions\n",
+	      argv[0]);
+      return 1;
+    }
+
   if (argc - optind == 2)
-    pnum = atoi(argv[optind + 1]);
+    {
+      pnum = atoi(argv[optind + 1]);
+
+      if (pnum < 0)
+	{
+	  fprintf(stderr, "%s: invalid partition number\n", argv[0]);
+	  return 1;
+	}
+
+      if (nparts == -1 && pnum > 0)
+	{
+	  fprintf(stderr, "%s: warning: ignoring partition number for"
+		  " non-partitioned medium\n", argv[0]);
+	  pnum = 0;
+	}
+      else if (nparts > 0 && pnum == 0)
+	{
+	  fprintf(stderr, "%s: cannot specify whole medium"
+		  " (has %d partition%s)\n", argv[0], nparts,
+		  nparts == 1 ? "" : "s");
+	  return 1;
+	}
+      else if (nparts > 0 && pnum > nparts)
+	{
+	  fprintf(stderr, "%s: invalid partition number (only %d available)\n",
+		  argv[0], nparts);
+	  return 1;
+	}
+    }
   else
     {
       if (nparts > 1)
 	{
-	  fprintf(stderr, "%s: must specify partition number\n", argv[0]);
+	  fprintf(stderr, "%s: must specify partition number (%d available)\n",
+		  argv[0], nparts);
 	  return 1;
 	}
       else if (nparts == -1)
