@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: util.c,v 1.6 1997/11/11 23:17:05 rob Exp rob $
+ * $Id: util.c,v 1.8 1998/02/19 20:15:54 rob Exp $
  */
 
 # include <stdio.h>
@@ -47,11 +47,35 @@ char *mctime(unsigned long secs)
 
 /*
  * NAME:	extstr()
+ * DESCRIPTION:	convert an extent descriptor into a printable string
+ */
+char *extstr(ExtDescriptor *ext)
+{
+  static char str[20];
+
+  switch (ext->xdrNumABlks)
+    {
+    case 0:
+      return "[]";
+
+    case 1:
+      sprintf(str, "1[%u]", ext->xdrStABN);
+      break;
+
+    default:
+      sprintf(str, "%u[%u..%u]", ext->xdrNumABlks,
+	      ext->xdrStABN, ext->xdrStABN + ext->xdrNumABlks - 1);
+    }
+
+  return str;
+}
+
+/*
+ * NAME:	extrecstr()
  * DESCRIPTION:	convert an extent record into a printable string
  */
-char *extstr(ExtDataRec *rec)
+char *extrecstr(ExtDataRec *rec)
 {
-  char extstr[20];
   static char str[60];
   ExtDescriptor *ext;
   int i;
@@ -60,26 +84,10 @@ char *extstr(ExtDataRec *rec)
 
   for (i = 0, ext = &(*rec)[0]; i < 3; ++i, ++ext)
     {
-      switch (ext->xdrNumABlks)
-	{
-	case 0:
-	  return (i == 0) ? "[]" : str;
-
-	case 1:
-	  sprintf(extstr, "1[%u]", ext->xdrStABN);
-	  break;
-
-	default:
-	  sprintf(extstr, "%u[%u..%u]",
-		  ext->xdrNumABlks,
-		  ext->xdrStABN,
-		  ext->xdrStABN + ext->xdrNumABlks - 1);
-	}
-
       if (i > 0)
 	strcat(str, "+");
 
-      strcat(str, extstr);
+      strcat(str, extstr(ext));
     }
 
   return str;
