@@ -16,10 +16,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: util.h,v 1.5 1998/01/08 21:14:26 rob Exp $
+ * $Id: util.h,v 1.6 1998/02/19 20:16:11 rob Exp $
  */
 
 char *mctime(unsigned long);
-char *extstr(ExtDataRec *);
+char *extstr(ExtDescriptor *);
+char *extrecstr(ExtDataRec *);
 void outhex(unsigned char *, unsigned int);
 int ask(char *, ...);
