@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: block.c,v 1.25 1998/01/08 21:15:02 rob Exp $
+ * $Id: block.c,v 1.27 1998/02/19 16:19:30 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -95,9 +95,9 @@ fail:
  */
 void b_showstats(const bcache *cache)
 {
-  fprintf(stderr, "BLOCK: CACHE vol 0x%lx \"%s\" hit/miss ratio = %.1f%%\n",
+  fprintf(stderr, "BLOCK: CACHE vol 0x%lx \"%s\" hit/miss ratio = %.3f\n",
 	  (unsigned long) cache->vol, cache->vol->mdb.drVN,
-	  cache->hits * 100.0 / cache->misses);
+	  (float) cache->hits / (float) cache->misses);
 }
 
 /*
@@ -783,12 +783,18 @@ unsigned long b_size(hfsvol *vol)
   if (nbytes != -1 && (unsigned long) nbytes >= HFS_BLOCKSZ)
     return (unsigned long) nbytes >> HFS_BLOCKSZ_BITS;
 
-  /* fall back on manual size detection */
+  /* manual size detection: first check there is at least 1 block in medium */
 
-  for (low = 0, high = 2879;
-       high > 0 && b_readpb(vol, high, &b, 1) != -1;
+  if (b_readpb(vol, 0, &b, 1) == -1)
+    ERROR(EIO, "size of medium indeterminable or empty");
+
+  for (low = 0, high = 2880;
+       high > 0 && b_readpb(vol, high - 1, &b, 1) != -1;
        high <<= 1)
-    low = high;
+    low = high - 1;
+
+  if (high == 0)
+    ERROR(EIO, "size of medium indeterminable or too large");
 
   /* common case: 1440K floppy */
 
@@ -797,7 +803,7 @@ unsigned long b_size(hfsvol *vol)
 
   /* binary search for other sizes */
 
-  while (high > 0 && low < high - 1)
+  while (low < high - 1)
     {
       mid = (low + high) >> 1;
 
@@ -807,9 +813,6 @@ unsigned long b_size(hfsvol *vol)
 	low = mid;
     }
 
-  if (high == 0)
-    ERROR(EIO, "cannot determine size of medium");
-
   return low + 1;
 
 fail:
