@@ -16,15 +16,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: block.h,v 1.9 1998/01/08 21:15:04 rob Exp $
+ * $Id: block.h,v 1.10 1998/02/19 15:14:35 rob Exp $
  */
 
 int b_init(hfsvol *);
 int b_flush(hfsvol *);
 int b_finish(hfsvol *);
 
-int b_readpb(hfsvol *, unsigned long, block *, unsigned int blen);
-int b_writepb(hfsvol *, unsigned long, const block *, unsigned int blen);
+int b_readpb(hfsvol *, unsigned long, block *, unsigned int);
+int b_writepb(hfsvol *, unsigned long, const block *, unsigned int);
 
 int b_readlb(hfsvol *, unsigned long, block *);
 int b_writelb(hfsvol *, unsigned long, const block *);
