@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: hfs.c,v 1.27 1998/01/08 21:15:15 rob Exp $
+ * $Id: hfs.c,v 1.29 1998/02/04 21:59:49 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -31,7 +31,6 @@
 # include "libhfs.h"
 # include "data.h"
 # include "block.h"
-# include "low.h"
 # include "medium.h"
 # include "file.h"
 # include "btree.h"
@@ -1573,7 +1572,6 @@ int hfs_format(const char *path, int pnum, const char *vname,
   hfsvol vol;
   btree *ext = &vol.ext;
   btree *cat = &vol.cat;
-  unsigned int vbmsz;
   int i;
   unsigned int *badalloc = 0;
 
@@ -1591,9 +1589,8 @@ int hfs_format(const char *path, int pnum, const char *vname,
 
   /* initialize volume geometry */
 
-  vol.lpa = 1 + (vol.vlen - 6) / 65536;
-
-  vbmsz = (vol.vlen / vol.lpa + 4095) / 4096;
+  vol.lpa = 1 + ((vol.vlen - 6) >> 16);
+  vol.vbmsz = (vol.vlen / vol.lpa + 0x0fff) >> 12;
 
   vol.mdb.drSigWord  = HFS_SIGWORD;
   vol.mdb.drCrDate   = d_mtime(time(0));
@@ -1602,10 +1599,10 @@ int hfs_format(const char *path, int pnum, const char *vname,
   vol.mdb.drNmFls    = 0;
   vol.mdb.drVBMSt    = 3;
   vol.mdb.drAllocPtr = 0;
-  vol.mdb.drNmAlBlks = (vol.vlen - 5 - vbmsz) / vol.lpa;
+  vol.mdb.drNmAlBlks = (vol.vlen - 5 - vol.vbmsz) / vol.lpa;
   vol.mdb.drAlBlkSiz = vol.lpa << HFS_BLOCKSZ_BITS;
-  vol.mdb.drClpSiz   = vol.mdb.drAlBlkSiz * 4;
-  vol.mdb.drAlBlSt   = 3 + vbmsz;
+  vol.mdb.drClpSiz   = vol.mdb.drAlBlkSiz << 2;
+  vol.mdb.drAlBlSt   = 3 + vol.vbmsz;
   vol.mdb.drNxtCNID  = HFS_CNID_ROOTDIR;  /* modified later */
   vol.mdb.drFreeBks  = vol.mdb.drNmAlBlks;
 
@@ -1614,8 +1611,10 @@ int hfs_format(const char *path, int pnum, const char *vname,
   vol.mdb.drVolBkUp  = 0;
   vol.mdb.drVSeqNum  = 0;
   vol.mdb.drWrCnt    = 0;
-  vol.mdb.drXTClpSiz = vol.mdb.drNmAlBlks / 128 * vol.mdb.drAlBlkSiz;
-  vol.mdb.drCTClpSiz = vol.mdb.drXTClpSiz;
+
+  /* vol.mdb.drXTClpSiz */
+  /* vol.mdb.drCTClpSiz */
+
   vol.mdb.drNmRtDirs = 0;
   vol.mdb.drFilCnt   = 0;
   vol.mdb.drDirCnt   = -1;  /* incremented when root directory is created */
@@ -1623,23 +1622,23 @@ int hfs_format(const char *path, int pnum, const char *vname,
   for (i = 0; i < 8; ++i)
     vol.mdb.drFndrInfo[i] = 0;
 
-  vol.mdb.drVCSize   = 0;
-  vol.mdb.drVBMCSize = 0;
-  vol.mdb.drCtlCSize = 0;
+  vol.mdb.drEmbedSigWord            = 0x0000;
+  vol.mdb.drEmbedExtent.xdrStABN    = 0;
+  vol.mdb.drEmbedExtent.xdrNumABlks = 0;
 
   /* vol.mdb.drXTFlSize */
   /* vol.mdb.drCTFlSize */
 
-  /* vol.mdb.drXTExtRec[0..3] */
-  /* vol.mdb.drCTExtRec[0..3] */
+  /* vol.mdb.drXTExtRec[0..2] */
+  /* vol.mdb.drCTExtRec[0..2] */
 
   /* initialize volume bitmap */
 
-  vol.vbm = ALLOC(block, vbmsz);
+  vol.vbm = ALLOC(block, vol.vbmsz);
   if (vol.vbm == 0)
     ERROR(ENOMEM, 0);
 
-  memset(vol.vbm, 0, vbmsz << HFS_BLOCKSZ_BITS);
+  memset(vol.vbm, 0, vol.vbmsz << HFS_BLOCKSZ_BITS);
 
   /* perform initial bad block sparing */
 
@@ -1680,7 +1679,7 @@ int hfs_format(const char *path, int pnum, const char *vname,
 
   /* create extents overflow file */
 
-  ext->f.cat.u.fil.filClpSize = vol.mdb.drXTClpSiz;
+  ext->f.cat.u.fil.filClpSize = vol.mdb.drNmAlBlks / 128 * vol.mdb.drAlBlkSiz;
 
   n_init(&ext->hdrnd, ext, ndHdrNode, 0);
 
@@ -1716,7 +1715,7 @@ int hfs_format(const char *path, int pnum, const char *vname,
 
   /* create catalog file */
 
-  cat->f.cat.u.fil.filClpSize = vol.mdb.drCTClpSiz;
+  cat->f.cat.u.fil.filClpSize = ext->f.cat.u.fil.filClpSize;
 
   n_init(&cat->hdrnd, cat, ndHdrNode, 0);
 
