@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: low.c,v 1.23 1998/01/08 21:15:19 rob Exp $
+ * $Id: low.c,v 1.24 1998/02/04 20:28:07 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -361,9 +361,9 @@ int l_getmdb(hfsvol *vol, MDB *mdb, int backup)
 
   ASSERT(ptr - b == 124);
 
-  d_fetchuw(&ptr, &mdb->drVCSize);
-  d_fetchuw(&ptr, &mdb->drVBMCSize);
-  d_fetchuw(&ptr, &mdb->drCtlCSize);
+  d_fetchuw(&ptr, &mdb->drEmbedSigWord);
+  d_fetchuw(&ptr, &mdb->drEmbedExtent.xdrStABN);
+  d_fetchuw(&ptr, &mdb->drEmbedExtent.xdrNumABlks);
 
   d_fetchul(&ptr, &mdb->drXTFlSize);
 
@@ -433,9 +433,9 @@ int l_putmdb(hfsvol *vol, const MDB *mdb, int backup)
 
   ASSERT(ptr - b == 124);
 
-  d_storeuw(&ptr, mdb->drVCSize);
-  d_storeuw(&ptr, mdb->drVBMCSize);
-  d_storeuw(&ptr, mdb->drCtlCSize);
+  d_storeuw(&ptr, mdb->drEmbedSigWord);
+  d_storeuw(&ptr, mdb->drEmbedExtent.xdrStABN);
+  d_storeuw(&ptr, mdb->drEmbedExtent.xdrNumABlks);
 
   d_storeul(&ptr, mdb->drXTFlSize);
 
