@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: medium.c,v 1.5 1998/01/09 16:18:08 rob Exp $
+ * $Id: medium.c,v 1.6 1998/01/15 21:28:25 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -203,7 +203,7 @@ int m_mkpart(hfsvol *vol,
 
   if (strlen(name) > 32 ||
       strlen(type) > 32)
-    ERROR(EINVAL, "partition name/type can be at most 32 chars");
+    ERROR(EINVAL, "partition name/type can each be at most 32 chars");
 
   if (len == 0)
     ERROR(EINVAL, "partition length must be > 0");
