@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: node.c,v 1.19 1998/01/08 21:15:26 rob Exp $
+ * $Id: node.c,v 1.20 1998/02/04 20:32:08 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -265,7 +265,7 @@ int split(node *left, byte *record, int *reclen)
     {
       byte *rec;
 
-      if (i < nrecs / 2)
+      if (i < (nrecs >> 1))
 	rec = HFS_NODEREC(*right, i);
       else
 	rec = HFS_NODEREC(*left, i);
