@@ -1,6 +1,6 @@
 /*
  * libhfs - library for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: record.c,v 1.13 1997/11/03 23:01:28 rob Exp $
+ * $Id: record.c,v 1.15 1998/01/08 21:15:31 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -238,10 +238,8 @@ void r_packcatdata(const CatDataRec *data, byte *pdata, int *len)
 
       break;
 
-# ifdef DEBUG
     default:
-      abort();
-# endif
+      ASSERT(0);
     }
 
   if (len)
@@ -361,10 +359,8 @@ void r_unpackcatdata(const byte *pdata, CatDataRec *data)
 
       break;
 
-# ifdef DEBUG
     default:
-      abort();
-# endif
+      ASSERT(0);
     }
 }
 
