@@ -16,13 +16,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: version.c,v 1.8 1998/01/09 16:19:02 rob Exp $
+ * $Id: version.c,v 1.10 1998/02/19 20:16:27 rob Exp $
  */
 
 # include "version.h"
 
-char libhfs_rcsid[] = "$Id: version.c,v 1.8 1998/01/09 16:19:02 rob Exp $";
+char libhfs_rcsid[] =
+  "$Id: version.c,v 1.10 1998/02/19 20:16:27 rob Exp $";
 
-char libhfs_version[]   = "libhfs version 3.1.1";
+char libhfs_version[]   = "libhfs version 3.2";
 char libhfs_copyright[] = "Copyright (C) 1996-1998 Robert Leslie";
 char libhfs_author[]    = "Robert Leslie <rob@mars.org>";
