@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: volume.c,v 1.26 1998/01/09 16:18:24 rob Exp $
+ * $Id: volume.c,v 1.28 1998/02/04 20:25:57 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -59,7 +59,7 @@ void v_init(hfsvol *vol, int flags)
   vol->cache      = 0;
 
   vol->vbm        = 0;
-  vol->cwd        = HFS_CNID_ROOTDIR;
+  vol->vbmsz      = 0;
 
   f_init(&ext->f, vol, HFS_CNID_EXT, "extents overflow");
 
@@ -79,6 +79,8 @@ void v_init(hfsvol *vol, int flags)
   cat->keyunpack  = (keyunpackfunc)  r_unpackcatkey;
   cat->keycompare = (keycomparefunc) r_comparecatkeys;
 
+  vol->cwd        = HFS_CNID_ROOTDIR;
+
   vol->refs       = 0;
   vol->files      = 0;
   vol->dirs       = 0;
@@ -104,7 +106,10 @@ int v_open(hfsvol *vol, const char *path, int mode)
   /* initialize volume block cache (OK to fail) */
 
   if (vol->flags & HFS_VOL_USECACHE)
-    b_init(vol);
+    {
+      if (b_init(vol) == -1)
+	vol->flags &= ~HFS_VOL_USECACHE;
+    }
 
   return 0;
 
@@ -200,7 +205,8 @@ int v_close(hfsvol *vol)
 
   FREE(vol->vbm);
 
-  vol->vbm = 0;
+  vol->vbm   = 0;
+  vol->vbmsz = 0;
 
   FREE(vol->ext.map);
   FREE(vol->cat.map);
@@ -370,7 +376,7 @@ fail:
 int v_readvbm(hfsvol *vol)
 {
   int vbmst = vol->mdb.drVBMSt;
-  int vbmsz = (vol->mdb.drNmAlBlks + 4095) / 4096;
+  int vbmsz = (vol->mdb.drNmAlBlks + 0x0fff) >> 12;
   block *bp;
 
   ASSERT(vol->vbm == 0);
@@ -382,6 +388,8 @@ int v_readvbm(hfsvol *vol)
   if (vol->vbm == 0)
     ERROR(ENOMEM, 0);
 
+  vol->vbmsz = vbmsz;
+
   for (bp = vol->vbm; vbmsz--; ++bp)
     {
       if (b_readlb(vol, vbmst++, bp) == -1)
@@ -392,7 +400,9 @@ int v_readvbm(hfsvol *vol)
 
 fail:
   FREE(vol->vbm);
-  vol->vbm = 0;
+
+  vol->vbm   = 0;
+  vol->vbmsz = 0;
 
   return -1;
 }
@@ -404,7 +414,7 @@ fail:
 int v_writevbm(hfsvol *vol)
 {
   int vbmst = vol->mdb.drVBMSt;
-  int vbmsz = (vol->mdb.drNmAlBlks + 4095) / 4096;
+  int vbmsz = vol->vbmsz;
   const block *bp;
 
   for (bp = vol->vbm; vbmsz--; ++bp)
