@@ -1,6 +1,6 @@
 /*
  * librsrc - library for reading and writing Macintosh resources
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: librsrc.h,v 1.6 1997/09/18 22:37:55 rob Exp $
+ * $Id: librsrc.h,v 1.8 1998/01/08 21:16:08 rob Exp $
  */
 
 # include "rsrc.h"
@@ -26,6 +26,12 @@ extern int errno;
 # define ERROR(code, str)  \
     do { rsrc_error = (str), errno = (code); goto fail; } while (0)
 
+# ifdef DEBUG
+#  define ASSERT(cond)	do { if (! (cond)) abort(); } while (0)
+# else
+#  define ASSERT(cond)	/* nothing */
+# endif
+
 # define SIZE(type, n)		((size_t) (sizeof(type) * (n)))
 # define ALLOC(type, n)		((type *) malloc(SIZE(type, n)))
 # define ALLOCX(type, n)	((n) ? ALLOC(type, n) : (type *) 0)
@@ -34,7 +40,7 @@ extern int errno;
 # define REALLOC(ptr, type, n)  \
     ((type *) ((ptr) ? realloc(ptr, SIZE(type, n)) : malloc(SIZE(type, n))))
 # define REALLOCX(ptr, type, n)  \
-    ((n) ? REALLOC(type, n) : (FREE(ptr), (type *) 0))
+    ((n) ? REALLOC(ptr, type, n) : (FREE(ptr), (type *) 0))
 
 # define BMTST(bm, num)  \
     (((byte *) (bm))[(num) >> 3]  &  (0x80 >> ((num) & 0x07)))
