@@ -16,13 +16,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: version.c,v 1.6 1997/11/11 23:14:39 rob Exp rob $
+ * $Id: version.c,v 1.9 1998/02/19 20:16:35 rob Exp $
  */
 
 # include "version.h"
 
-char librsrc_rcsid[] = "$Id: version.c,v 1.6 1997/11/11 23:14:39 rob Exp rob $";
+char librsrc_rcsid[] =
+  "$Id: version.c,v 1.9 1998/02/19 20:16:35 rob Exp $";
 
-char librsrc_version[]   = "librsrc version 3.1.1";
+char librsrc_version[]   = "librsrc version 3.2";
 char librsrc_copyright[] = "Copyright (C) 1996-1998 Robert Leslie";
 char librsrc_author[]    = "Robert Leslie <rob@mars.org>";
