@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: hdump.c,v 1.3 1998/01/08 21:16:43 rob Exp $
+ * $Id: hdump.c,v 1.5 1998/01/12 18:35:35 rob Exp $
  */
 
 # include <stdio.h>
@@ -58,7 +58,7 @@ int main(int argc, char *argv[])
     fprintf(stderr, "block 0: not a valid driver descriptor record\n");
   else
     {
-      printf("===== Driver Descriptor Record =====\n");
+      printf("Driver Descriptor Record\n");
       printf("  sbSig      \t= 0x%04x\n",  ddr.sbSig);
       printf("  sbBlkSize  \t= %d\n",  ddr.sbBlkSize);
       printf("  sbBlkCount \t= %ld\n", ddr.sbBlkCount);
@@ -73,9 +73,9 @@ int main(int argc, char *argv[])
 
       for (i = 0; i < 243; i += 4)
 	{
-	  ddr.ddBlock = d_getsl((char *) &ddr.ddPad[i]);
-	  ddr.ddSize  = d_getsw((char *) &ddr.ddPad[i + 2]);
-	  ddr.ddType  = d_getsw((char *) &ddr.ddPad[i + 3]);
+	  ddr.ddBlock = d_getsl((unsigned char *) &ddr.ddPad[i]);
+	  ddr.ddSize  = d_getsw((unsigned char *) &ddr.ddPad[i + 2]);
+	  ddr.ddType  = d_getsw((unsigned char *) &ddr.ddPad[i + 3]);
 
 	  if (ddr.ddBlock != 0 ||
 	      ddr.ddSize  != 0 ||
@@ -103,7 +103,7 @@ int main(int argc, char *argv[])
 	  goto fail;
 	}
 
-      printf("===== Partition Entry %lu =====\n", bnum);
+      printf("Partition Entry %lu\n", bnum);
       printf("  pmSig        \t= 0x%04x\n", map.pmSig);
       printf("  pmSigPad     \t= %d\n",     map.pmSigPad);
       printf("  pmMapBlkCnt  \t= %ld\n",    map.pmMapBlkCnt);
