@@ -1,6 +1,6 @@
 /*
  * hfsutils - tools for reading and writing Macintosh HFS volumes
- * Copyright (C) 1996, 1997 Robert Leslie
+ * Copyright (C) 1996-1998 Robert Leslie
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,13 +16,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: suid.c,v 1.6 1997/11/11 21:35:55 rob Exp $
+ * $Id: suid.c,v 1.9 1998/01/08 21:17:01 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
 #  include "config.h"
 # endif
 
+# include <sys/types.h>
+
 # ifdef HAVE_UNISTD_H
 #  include <unistd.h>
 # else
@@ -30,8 +32,13 @@ uid_t getuid(void);
 uid_t geteuid(void);
 gid_t getgid(void);
 gid_t getegid(void);
+#  ifdef HAVE_SETREUID
 int setreuid(uid_t, uid_t);
 int setregid(gid_t, gid_t);
+#  else
+int setuid(uid_t);
+int setgid(gid_t);
+#  endif
 # endif
 
 # include "suid.h"
@@ -60,8 +67,17 @@ void suid_init(void)
  */
 void suid_enable(void)
 {
+# ifdef HAVE_SETREUID
+
   setreuid(-1, euid);
   setregid(-1, egid);
+
+# else
+
+  setuid(euid);
+  setgid(egid);
+
+# endif
 }
 
 /*
@@ -70,6 +86,15 @@ void suid_enable(void)
  */
 void suid_disable(void)
 {
+# ifdef HAVE_SETREUID
+
   setreuid(-1, uid);
   setregid(-1, gid);
+
+# else
+
+  setuid(uid);
+  setgid(gid);
+
+# endif
 }
