@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: tclhfs.c,v 1.26 1998/01/08 21:17:04 rob Exp rob $
+ * $Id: tclhfs.c,v 1.28 1998/02/19 19:34:51 rob Exp $
  */
 
 # ifdef HAVE_CONFIG_H
@@ -1081,6 +1081,13 @@ int vol_cmd(ClientData clientData, Tcl_Interp *interp,
 	  fileref *fref;
 	  hfsfile *file;
 
+	  if (strlen(argv[3]) != 4 ||
+	      strlen(argv[4]) != 4)
+	    {
+	      interp->result = "type and creator must be 4 character strings";
+	      return TCL_ERROR;
+	    }
+
 	  fref = ALLOC(fileref, 1);
 	  if (fref == 0)
 	    {
