@@ -27,6 +27,17 @@ proc mkvol {{size 1440} {path "image.hfs"}} {
     hformat $path 0 "Test Volume"
 }
 
+#
+# NAME:		remount
+# DESCRIPTION:	flush and remount a volume
+#
+proc remount {{path "image.hfs"}} {
+    puts "Remounting $path ..."
+
+    humount $path
+    hmount $path 0
+}
+
 foreach test [glob test*.tcl] {
     source $test
 }
